@@ -114,6 +114,10 @@ private:
     // TCP version which supports rate limiting per -b
     void RunRateLimitedTCP(void);
     void RunNearCongestionTCP(void);
+#if HAVE_DECL_TCP_NOTSENT_LOWAT
+    bool AwaitWriteSelectEventTCP(void);
+    void RunWriteEventsTCP(void);
+#endif
     // UDP traffic with isochronous and vbr support
     void RunUDPIsochronous(void);
     // UDP plain
@@ -127,7 +131,6 @@ private:
     int mySocket;
 #endif
     struct ReporterData *myReport;
-    char* mBuf;
     Timestamp mEndTime;
     Timestamp lastPacketTime;
     Timestamp now;
