@@ -214,17 +214,24 @@ struct ReportCommon {
     int BufLen;
     int MSS;
     int TCPWin;
+#if HAVE_DECL_TCP_WINDOW_CLAMP
+    int ClampSize;
+#endif
+#if HAVE_DECL_TCP_NOTSENT_LOWAT
+    int WritePrefetch;
+#endif
     int winsize_requested;
     unsigned int FQPacingRate;
-    int RXbins;
-    int RXbinsize;
-    int RXunits;
+    int HistBins;
+    int HistBinsize;
+    int HistUnits;
     double pktIPG;
     iperf_sockaddr peer;
     Socklen_t size_peer;
     iperf_sockaddr local;
     Socklen_t size_local;
     char* Host;                   // -c
+    char* HideHost;
     char* Localhost;              // -B
     char* Ifrname;
     char* Ifrnametx;
@@ -544,7 +551,7 @@ void PrintMSS(struct ReporterData *data);
 void reporter_default_heading_flags(int);
 void reporter_connect_printf_tcp_final(struct ConnectionInfo *report);
 
-void write_UDP_AckFIN(struct TransferInfo *stats);
+void write_UDP_AckFIN(struct TransferInfo *stats, int len);
 
 int reporter_process_transfer_report (struct ReporterData *this_ireport);
 int reporter_process_report (struct ReportHeader *reporthdr);
