@@ -156,15 +156,18 @@ struct thread_Settings {
     // Pointers
     char*  mFileName;               // -F
     char*  mHost;                   // -c
+    char*  mHideHost;
     char*  mLocalhost;              // -B
     char*  mOutputFileName;         // -o
     char*  mIfrname;                // %<device> name (for rx)
     char*  mIfrnametx;              // %<device> name (for tx)
     char*  mSSMMulticastStr;        // --ssm-host
     char*  mIsochronousStr;         // --isochronous
-    char*  mRxHistogramStr;         // --histograms (packets)
+    char*  mHistogramStr;         // --histograms (packets)
     char*  mTransferIDStr;          //
+    char*  mBuf;
     FILE*  Extractor_file;
+
     struct ReportHeader* reporthdr;
     struct SumReport* mSumReport;
     struct SumReport* mFullDuplexReport;
@@ -213,7 +216,6 @@ struct thread_Settings {
     int flags;
     int flags_extend;
     int flags_extend2;
-    int skip;
     // enums (which should be special int's)
     enum ThreadMode mThreadMode;         // -s or -c
     enum ReportMode mReportMode;
@@ -222,7 +224,7 @@ struct thread_Settings {
     // Hopefully int64_t's
     uintmax_t mAppRate;            // -b or -u
     char mAppRateUnits;            // -b is either bw or pps
-    uintmax_t mAmount;             // -n or -t
+    uintmax_t mAmount;             // -n or -t time unit is 10 ms
     unsigned int mInterval;               // -i integer time units is usec
     enum IntervalMode mIntervalMode;
     // shorts
@@ -245,11 +247,11 @@ struct thread_Settings {
     int incrsrcport;
     int connectonly_count;
     char* mCongestion;
-    int mRXbins;
-    int mRXbinsize;
-    int mRXunits;
-    double mRXci_lower;
-    double mRXci_upper;
+    int mHistBins;
+    int mHistBinsize;
+    int mHistUnits;
+    double mHistci_lower;
+    double mHistci_upper;
 #if defined(HAVE_WIN32_THREAD)
     HANDLE mHandle;
 #endif
@@ -266,6 +268,7 @@ struct thread_Settings {
     struct timeval txholdback_timer;
     struct timeval txstart_epoch;
     struct timeval accept_time;
+    struct timeval sent_time;
     struct Condition awake_me;
     struct PacketRing *ackring;
     struct BarrierMutex *connects_done;
@@ -278,6 +281,14 @@ struct thread_Settings {
     struct timeval mPermitKeyTime;
     bool mKeyCheck;
     double mListenerTimeout;
+    int tuntapdev;
+    int firstreadbytes;
+#if HAVE_DECL_TCP_WINDOW_CLAMP
+    int mClampSize;
+#endif
+#if HAVE_DECL_TCP_NOTSENT_LOWAT
+    int mWritePrefetch;
+#endif
 };
 
 /*
@@ -329,7 +340,7 @@ struct thread_Settings {
 #define FLAG_REVERSE        0x00000004
 #define FLAG_ISOCHRONOUS    0x00000008
 #define FLAG_UDPUNUSED      0x00000010
-#define FLAG_RXHISTOGRAM    0x00000020
+#define FLAG_HISTOGRAM      0x00000020
 #define FLAG_L2LENGTHCHECK  0x00000100
 #define FLAG_TXSTARTTIME    0x00000200
 #define FLAG_INCRDSTIP      0x00000400
@@ -354,12 +365,18 @@ struct thread_Settings {
 #define FLAG_SETTCPMSS      0x20000000
 #define FLAG_INCRDSTPORT    0x40000000
 #define FLAG_INCRSRCIP      0x80000000
+
 /*
  * More extended flags
  */
 #define FLAG_PERIODICBURST  0x00000001
 #define FLAG_SUMDSTIP       0x00000002
 #define FLAG_SMALLTRIPTIME  0x00000004
+#define FLAG_RXCLAMP        0x00000008
+#define FLAG_WRITEPREFETCH  0x00000010
+#define FLAG_TUNDEV         0x00000020
+#define FLAG_TAPDEV         0x00000040
+#define FLAG_HIDEIPS        0x00000080
 
 #define isBuflenSet(settings)      ((settings->flags & FLAG_BUFLENSET) != 0)
 #define isCompat(settings)         ((settings->flags & FLAG_COMPAT) != 0)
@@ -397,7 +414,7 @@ struct thread_Settings {
 #define isFullDuplex(settings)          ((settings->flags_extend & FLAG_FULLDUPLEX) != 0)
 #define isServerReverse(settings)  ((settings->flags_extend & FLAG_SERVERREVERSE) != 0)
 #define isIsochronous(settings)    ((settings->flags_extend & FLAG_ISOCHRONOUS) != 0)
-#define isRxHistogram(settings)    ((settings->flags_extend & FLAG_RXHISTOGRAM) != 0)
+#define isHistogram(settings)    ((settings->flags_extend & FLAG_HISTOGRAM) != 0)
 #define isL2LengthCheck(settings)  ((settings->flags_extend & FLAG_L2LENGTHCHECK) != 0)
 #define isIncrDstIP(settings)      ((settings->flags_extend & FLAG_INCRDSTIP) != 0)
 #define isIncrSrcIP(settings)      ((settings->flags_extend & FLAG_INCRSRCIP) != 0)
@@ -423,6 +440,11 @@ struct thread_Settings {
 #define isTCPMSS(settings)         ((settings->flags_extend & FLAG_SETTCPMSS) != 0)
 #define isPeriodicBurst(settings)  ((settings->flags_extend2 & FLAG_PERIODICBURST) != 0)
 #define isSumServerDstIP(settings) ((settings->flags_extend2 & FLAG_SUMDSTIP) != 0)
+#define isRxClamp(settings)        ((settings->flags_extend2 & FLAG_RXCLAMP) != 0)
+#define isWritePrefetch(settings) ((settings->flags_extend2 & FLAG_WRITEPREFETCH) != 0)
+#define isTapDev(settings)         ((settings->flags_extend2 & FLAG_TAPDEV) != 0)
+#define isTunDev(settings)         ((settings->flags_extend2 & FLAG_TUNDEV) != 0)
+#define isHideIPs(settings)        ((settings->flags_extend2 & FLAG_HIDEIPS) != 0)
 
 #define setBuflenSet(settings)     settings->flags |= FLAG_BUFLENSET
 #define setCompat(settings)        settings->flags |= FLAG_COMPAT
@@ -458,7 +480,7 @@ struct thread_Settings {
 #define setFullDuplex(settings)    settings->flags_extend |= FLAG_FULLDUPLEX
 #define setServerReverse(settings) settings->flags_extend |= FLAG_SERVERREVERSE
 #define setIsochronous(settings)   settings->flags_extend |= FLAG_ISOCHRONOUS
-#define setRxHistogram(settings)   settings->flags_extend |= FLAG_RXHISTOGRAM
+#define setHistogram(settings)   settings->flags_extend |= FLAG_HISTOGRAM
 #define setL2LengthCheck(settings) settings->flags_extend |= FLAG_L2LENGTHCHECK
 #define setIncrDstIP(settings)     settings->flags_extend |= FLAG_INCRDSTIP
 #define setIncrSrcIP(settings)     settings->flags_extend |= FLAG_INCRSRCIP
@@ -483,6 +505,11 @@ struct thread_Settings {
 #define setTCPMSS(settings)        settings->flags_extend |= FLAG_SETTCPMSS
 #define setPeriodicBurst(settings) settings->flags_extend2 |= FLAG_PERIODICBURST
 #define setSumServerDstIP(settings) settings->flags_extend2 |= FLAG_SUMDSTIP
+#define setRxClamp(settings)       settings->flags_extend2 |= FLAG_RXCLAMP
+#define setWritePrefetch(settings) settings->flags_extend2 |= FLAG_WRITEPREFETCH
+#define setTapDev(settings)        settings->flags_extend2 |= FLAG_TAPDEV
+#define setTunDev(settings)        settings->flags_extend2 |= FLAG_TUNDEV
+#define setHideIPs(settings)       settings->flags_extend2 |= FLAG_HIDEIPS
 
 #define unsetBuflenSet(settings)   settings->flags &= ~FLAG_BUFLENSET
 #define unsetCompat(settings)      settings->flags &= ~FLAG_COMPAT
@@ -518,7 +545,7 @@ struct thread_Settings {
 #define unsetFullDuplex(settings)  settings->flags_extend &= ~FLAG_FULLDUPLEX
 #define unsetServerReverse(settings) settings->flags_extend &= ~FLAG_SERVERREVERSE
 #define unsetIsochronous(settings)  settings->flags_extend &= ~FLAG_ISOCHRONOUS
-#define unsetRxHistogram(settings)  settings->flags_extend &= ~FLAG_RXHISTOGRAM
+#define unsetHistogram(settings)  settings->flags_extend &= ~FLAG_HISTOGRAM
 #define unsetL2LengthCheck(settings)  settings->flags_extend &= ~FLAG_L2LENGTHCHECK
 #define unsetIncrDstIP(settings)    settings->flags_extend &= ~FLAG_INCRDSTIP
 #define unsetIncrSrcIP(settings)    settings->flags_extend &= ~FLAG_INCRSRCIP
@@ -542,6 +569,11 @@ struct thread_Settings {
 #define unsetTCPMSS(settings)        settings->flags_extend &= ~FLAG_SETTCPMSS
 #define unsetPeriodicBurst(settings) settings->flags_extend2 &= ~FLAG_PERIODICBURST
 #define unsetSumServerDstIP(settings) settings->flags_extend2 &= ~FLAG_SUMDSTIP
+#define unsetRxClamp(settings)       settings->flags_extend2 &= ~FLAG_RXCLAMP
+#define unsetWritePrefetch(settings) settings->flags_extend2 &= ~FLAG_WRITEPREFETCH
+#define unsetTapDev(settings)        settings->flags_extend2 &= ~FLAG_TAPDEV
+#define unsetTunDev(settings)        settings->flags_extend2 &= ~FLAG_TUNDEV
+#define unsetHideIPs(settings)       settings->flags_extend2 &= ~FLAG_HIDEIPS
 
 // set to defaults
 void Settings_Initialize(struct thread_Settings* main);
@@ -573,7 +605,7 @@ void Settings_GenerateClientSettings(struct thread_Settings *server, struct thre
 // generate client header for server
 int Settings_GenerateClientHdr(struct thread_Settings *client, void * hdr, struct timeval startTime);
 
-int Settings_ClientHdrPeekLen(uint32_t flags);
+int Settings_ClientTestHdrLen(uint32_t flags, struct thread_Settings *inSettings);
 
 #ifdef __cplusplus
 } /* end extern "C" */
