@@ -54,6 +54,9 @@ extern "C" {
 /*
  * Message header flags
  */
+
+#define TAPBYTESSLOP 512
+
 /* key for permit */
 #define HEADER_KEYCHECK     0x10000000
 #define HEADER_KEYL1        0x01000000
@@ -74,13 +77,13 @@ extern "C" {
 #define HEADER_AVOID2        0x02000000
 #define HEADER_AVOID1        0x01000000
 #define HEADER_V2PEERDETECT  0x02000000
-#define HEADER32_SMALL_TRIPTIMES 0x04000000
+#define HEADER32_SMALL_TRIPTIMES 0x00020000
 #define HEADER_LEN_BIT       0x00010000
 #define HEADER_LEN_MASK      0x000001FE
 #define MAX_HEADER_LEN       256
 #define SERVER_HEADER_EXTEND 0x40000000
 #define RUN_NOW              0x00000001
-#define HEADER16_SMALL_TRIPTIMES 0x0400 // use is 16 bits and not 32 bits
+#define HEADER16_SMALL_TRIPTIMES 0x0002 // use is 16 bits and not 32 bits
 
 // newer flags available per HEADER_EXTEND
 // Below flags are used to pass test settings in *every* UDP packet
@@ -99,6 +102,7 @@ extern "C" {
 #define HEADER_FULLDUPLEX     0x0800
 #define HEADER_EPOCH_START    0x1000
 #define HEADER_PERIODICBURST  0x2000
+#define HEADER_WRITEPREFETCH  0x4000
 
 // later features
 #define HDRXACKMAX 2500000 // default 2.5 seconds, units microseconds
@@ -202,7 +206,7 @@ struct client_hdrext {
     uint16_t tos;
     uint32_t lRate;
     uint32_t uRate;
-    int32_t Realtime;
+    uint32_t TCPWritePrefetch;
 };
 
 struct client_hdrext_starttime_fq {
@@ -407,6 +411,15 @@ struct client_udpsmall_testhdr {
     uint16_t flags;
 };
 
+struct client_hdr_ack_ts {
+    uint32_t sent_tv_sec;
+    uint32_t sent_tv_usec;
+    uint32_t sentrx_tv_sec;
+    uint32_t sentrx_tv_usec;
+    uint32_t ack_tv_sec;
+    uint32_t ack_tv_usec;
+};
+
 struct client_hdr_ack {
     struct hdr_typelen typelen;
     uint32_t flags;
@@ -414,6 +427,7 @@ struct client_hdr_ack {
     uint32_t version_l;
     uint32_t reserved1;
     uint32_t reserved2;
+    struct client_hdr_ack_ts ts;
 };
 
 /*
@@ -449,7 +463,7 @@ struct client_hdr_ack {
  *                +--------+--------+--------+--------+
  *            14  |        rate units                 |
  *                +--------+--------+--------+--------+
- *            15  |        realtime   (0.13)          |
+ *            15  |        write prefetch   (0.13)    |
  *                +--------+--------+--------+--------+
  *            16  |        reserved (0.14 start)      |
  *                +--------+--------+--------+--------+
