@@ -942,6 +942,11 @@ void reporter_handle_packet_client (struct ReporterData *data, struct ReportStru
 	} else if (isPeriodicBurst(stats->common)) {
 	    reporter_handle_burst_tcp_client_transit(data, packet);
 	}
+#if HAVE_DECL_TCP_NOTSENT_LOWAT
+	if (stats->latency_histogram && (packet->select_delay > 0.0)) {
+	   histogram_insert(stats->latency_histogram, packet->select_delay, &packet->packetTime);
+       }
+#endif
     }
     if (isUDP(stats->common)) {
 	stats->PacketID = packet->packetID;
@@ -1092,10 +1097,18 @@ void reporter_transfer_protocol_server_udp (struct ReporterData *data, int final
 	stats->cntError = 0;
     stats->cntDatagrams = stats->PacketID - stats->total.Datagrams.prev;
     stats->cntIPG = stats->total.IPG.current - stats->total.IPG.prev;
+    if (stats->latency_histogram) {
+        stats->latency_histogram->final = 1;
+    }
+
     if (isIsochronous(stats->common)) {
 	stats->isochstats.cntFrames = stats->isochstats.framecnt.current - stats->isochstats.framecnt.prev;
 	stats->isochstats.cntFramesMissed = stats->isochstats.framelostcnt.current - stats->isochstats.framelostcnt.prev;
 	stats->isochstats.cntSlips = stats->isochstats.slipcnt.current - stats->isochstats.slipcnt.prev;
+	if (stats->framelatency_histogram) {
+	    stats->framelatency_histogram->final = 1;
+	}
+
     }
     if (stats->total.Datagrams.current == 1)
 	stats->jitter = 0;
@@ -1305,6 +1318,9 @@ void reporter_transfer_protocol_server_tcp (struct ReporterData *data, int final
     struct TransferInfo *fullduplexstats = (data->FullDuplexReport != NULL) ? &data->FullDuplexReport->info : NULL;
     stats->cntBytes = stats->total.Bytes.current - stats->total.Bytes.prev;
     int ix;
+    if (stats->framelatency_histogram) {
+        stats->framelatency_histogram->final = 0;
+    }
     if (sumstats) {
 	sumstats->threadcnt++;
 	sumstats->total.Bytes.current += stats->cntBytes;
@@ -1319,6 +1335,9 @@ void reporter_transfer_protocol_server_tcp (struct ReporterData *data, int final
 	fullduplexstats->total.Bytes.current += stats->cntBytes;
     }
     if (final) {
+        if (stats->framelatency_histogram) {
+	    stats->framelatency_histogram->final = 1;
+	}
 	if ((stats->cntBytes > 0) && stats->output_handler && !TimeZero(stats->ts.intervalTime)) {
 	    // print a partial interval report if enable and this a final
 	    if ((stats->output_handler) && !(stats->filter_this_sample_output)) {
@@ -1374,6 +1393,11 @@ void reporter_transfer_protocol_client_tcp (struct ReporterData *data, int final
     struct TransferInfo *sumstats = (data->GroupSumReport != NULL) ? &data->GroupSumReport->info : NULL;
     struct TransferInfo *fullduplexstats = (data->FullDuplexReport != NULL) ? &data->FullDuplexReport->info : NULL;
     stats->cntBytes = stats->total.Bytes.current - stats->total.Bytes.prev;
+#if HAVE_DECL_TCP_NOTSENT_LOWAT
+    if (stats->latency_histogram) {
+        stats->latency_histogram->final = 0;
+    }
+#endif
     if (isIsochronous(stats->common)) {
 	if (final) {
 	    stats->isochstats.cntFrames = stats->isochstats.framecnt.current;
@@ -1401,6 +1425,11 @@ void reporter_transfer_protocol_client_tcp (struct ReporterData *data, int final
 	fullduplexstats->total.Bytes.current += stats->cntBytes;
     }
     if (final) {
+#if HAVE_DECL_TCP_NOTSENT_LOWAT
+	if (stats->latency_histogram) {
+	    stats->latency_histogram->final = 1;
+	}
+#endif
 	if ((stats->cntBytes > 0) && stats->output_handler && !TimeZero(stats->ts.intervalTime)) {
 	    // print a partial interval report if enable and this a final
 	    if ((stats->output_handler) && !(stats->filter_this_sample_output)) {
@@ -1425,6 +1454,9 @@ void reporter_transfer_protocol_client_tcp (struct ReporterData *data, int final
 #ifdef HAVE_STRUCT_TCP_INFO_TCPI_TOTAL_RETRANS
 	stats->sock_callstats.write.TCPretry = stats->sock_callstats.write.totTCPretry;
 #endif
+	if (stats->framelatency_histogram) {
+	    stats->framelatency_histogram->final = 1;
+	}
 	stats->cntBytes = stats->total.Bytes.current;
 	reporter_set_timestamps_time(&stats->ts, TOTAL);
     } else if (isIsochronous(stats->common)) {
@@ -1432,7 +1464,6 @@ void reporter_transfer_protocol_client_tcp (struct ReporterData *data, int final
 	stats->isochstats.cntFramesMissed = stats->isochstats.framelostcnt.current - stats->isochstats.framelostcnt.prev;
 	stats->isochstats.cntSlips = stats->isochstats.slipcnt.current - stats->isochstats.slipcnt.prev;
     }
-
     if ((stats->output_handler) && !(stats->filter_this_sample_output)) {
 	(*stats->output_handler)(stats);
     }
