@@ -84,6 +84,7 @@ static void common_copy (struct ReportCommon **common, struct thread_Settings *i
     *common = (struct ReportCommon *) calloc(1, sizeof(struct ReportCommon));
     int bytecnt = 0;
     bytecnt = my_str_copy(&(*common)->Host, inSettings->mHost);
+    bytecnt += my_str_copy(&(*common)->HideHost, inSettings->mHideHost);
     bytecnt += my_str_copy(&(*common)->Localhost, inSettings->mLocalhost);
     bytecnt += my_str_copy(&(*common)->Ifrname, inSettings->mIfrname);
     bytecnt += my_str_copy(&(*common)->Ifrnametx, inSettings->mIfrnametx);
@@ -91,6 +92,7 @@ static void common_copy (struct ReportCommon **common, struct thread_Settings *i
     bytecnt += my_str_copy(&(*common)->Congestion, inSettings->mCongestion);
     bytecnt += my_str_copy(&(*common)->transferIDStr, inSettings->mTransferIDStr);
     bytecnt += my_str_copy(&(*common)->PermitKey, inSettings->mPermitKey);
+
     // copy some relevant settings
     (*common)->flags = inSettings->flags;
     (*common)->flags_extend = inSettings->flags_extend;
@@ -123,14 +125,19 @@ static void common_copy (struct ReportCommon **common, struct thread_Settings *i
     (*common)->size_peer = inSettings->size_peer;
     (*common)->local = inSettings->local;
     (*common)->size_local = inSettings->size_local;
-    (*common)->RXbins =inSettings->mRXbins;
-    (*common)->RXbinsize =inSettings->mRXbinsize;
-    (*common)->RXunits =inSettings->mRXunits;
+    (*common)->HistBins =inSettings->mHistBins;
+    (*common)->HistBinsize =inSettings->mHistBinsize;
+    (*common)->HistUnits =inSettings->mHistUnits;
     (*common)->pktIPG =inSettings->mBurstIPG;
     (*common)->rtt_weight =inSettings->rtt_nearcongest_divider;
     (*common)->ListenerTimeout =inSettings->mListenerTimeout;
     (*common)->FPS = inSettings->mFPS;
-
+#if HAVE_DECL_TCP_WINDOW_CLAMP
+    (*common)->ClampSize = inSettings->mClampSize;
+#endif
+#if HAVE_DECL_TCP_NOTSENT_LOWAT
+    (*common)->WritePrefetch = inSettings->mWritePrefetch;
+#endif
 #ifdef HAVE_STRUCT_TCP_INFO_TCPI_TOTAL_RETRANS
     (*common)->enable_sampleTCPstats = false;
     (*common)->intervalonly_sampleTCPstats = false;
@@ -157,6 +164,8 @@ static void free_common_copy (struct ReportCommon *common) {
     // Free deep copies
     if (common->Host)
 	free(common->Host);
+    if (common->HideHost)
+	free(common->HideHost);
     if (common->Localhost)
 	free(common->Localhost);
     if (common->Ifrname)
@@ -624,20 +633,28 @@ struct ReportHeader* InitIndividualReport (struct thread_Settings *inSettings) {
 
     if (inSettings->mThreadMode == kMode_Server) {
 	ireport->info.sock_callstats.read.binsize = inSettings->mBufLen / 8;
-	if (isRxHistogram(inSettings) && isUDP(inSettings) && isTripTime(inSettings)) {
+	if (isHistogram(inSettings) && isUDP(inSettings) && isTripTime(inSettings)) {
 	    char name[] = "T8";
-	    ireport->info.latency_histogram =  histogram_init(inSettings->mRXbins,inSettings->mRXbinsize,0,\
-							      pow(10,inSettings->mRXunits), \
-							      inSettings->mRXci_lower, inSettings->mRXci_upper, ireport->info.common->transferID, name);
+	    ireport->info.latency_histogram =  histogram_init(inSettings->mHistBins,inSettings->mHistBinsize,0,\
+							      pow(10,inSettings->mHistUnits), \
+							      inSettings->mHistci_lower, inSettings->mHistci_upper, ireport->info.common->transferID, name);
 	}
-	if (isRxHistogram(inSettings) && (isIsochronous(inSettings) || (!isUDP(inSettings) && isTripTime(inSettings)))) {
+	if (isHistogram(inSettings) && (isIsochronous(inSettings) || (!isUDP(inSettings) && isTripTime(inSettings)))) {
 	    char name[] = "F8";
 	    // make sure frame bin size min is 100 microsecond
-	    ireport->info.framelatency_histogram =  histogram_init(inSettings->mRXbins,inSettings->mRXbinsize,0, \
-								   pow(10,inSettings->mRXunits), inSettings->mRXci_lower, \
-								   inSettings->mRXci_upper, ireport->info.common->transferID, name);
+	    ireport->info.framelatency_histogram =  histogram_init(inSettings->mHistBins,inSettings->mHistBinsize,0, \
+								   pow(10,inSettings->mHistUnits), inSettings->mHistci_lower, \
+								   inSettings->mHistci_upper, ireport->info.common->transferID, name);
 	}
     }
+#if HAVE_DECL_TCP_NOTSENT_LOWAT
+    if ((inSettings->mThreadMode == kMode_Client) && isWritePrefetch(inSettings) && !isUDP(inSettings) && isHistogram(inSettings)) {
+	char name[] = "S8";
+	ireport->info.latency_histogram =  histogram_init(inSettings->mHistBins,inSettings->mHistBinsize,0,\
+							  pow(10,inSettings->mHistUnits), \
+							  inSettings->mHistci_lower, inSettings->mHistci_upper, ireport->info.common->transferID, name);
+    }
+#endif
     return reporthdr;
 }
 
@@ -701,6 +718,11 @@ struct ReportHeader* InitConnectionReport (struct thread_Settings *inSettings, d
     if (inSettings->mSock > 0) {
 	creport->winsize = getsock_tcp_windowsize(inSettings->mSock,	\
                   (inSettings->mThreadMode != kMode_Client ? 0 : 1) );
+#if HAVE_DECL_TCP_WINDOW_CLAMP
+	if (isRxClamp(inSettings)) {
+	    getsock_tcp_windowclamp(inSettings->mSock);
+	}
+#endif
     }
     creport->common->winsize_requested = inSettings->mTCPWin;
     creport->txholdbacktime = inSettings->txholdback_timer;
@@ -839,12 +861,17 @@ struct ReportHeader* InitServerRelayUDPReport(struct thread_Settings *inSettings
  * termination datagrams, so re-transmit our AckFIN.
  * Sent by server to client
  * ------------------------------------------------------------------- */
-void write_UDP_AckFIN (struct TransferInfo *stats) {
+void write_UDP_AckFIN (struct TransferInfo *stats, int len) {
     assert(stats!= NULL);
     int ackpacket_length = (int) (sizeof(struct UDP_datagram) + sizeof(struct server_hdr));
-    char *ackPacket = (char *) calloc(1, ackpacket_length);
+    char *ackPacket = (char *) calloc(1, len);
     int success = 0;
     assert(ackPacket);
+    fd_set readSet;
+    int rc = 1;
+    struct timeval timeout;
+    int readlen = ((ackpacket_length * 2) > len * 2) ? (ackpacket_length * 2) : (len * 2);
+
     if (ackPacket) {
 	struct UDP_datagram *UDP_Hdr = (struct UDP_datagram *)ackPacket;
 	struct server_hdr *hdr = (struct server_hdr *)(UDP_Hdr+1);
@@ -895,8 +922,6 @@ void write_UDP_AckFIN (struct TransferInfo *stats) {
 #define TRYCOUNT 10
 	int count = TRYCOUNT;
 	while (--count) {
-	    int rc;
-	    struct timeval timeout;
 	    // write data
 #if defined(HAVE_LINUX_FILTER_H) && defined(HAVE_AF_PACKET)
 	    // If in l2mode, use the AF_INET socket to write this packet
@@ -910,7 +935,7 @@ void write_UDP_AckFIN (struct TransferInfo *stats) {
 #endif
 	    WARN_errno(rc < 0, "write-ackfin");
 	    // wait here is for silence, no more packets from the client
-	    fd_set readSet;
+
 	    FD_ZERO(&readSet);
 	    FD_SET(stats->common->socket, &readSet);
 	    timeout.tv_sec  = 0;
@@ -923,15 +948,16 @@ void write_UDP_AckFIN (struct TransferInfo *stats) {
 		success = 1;
 		break;
 	    }
-	    rc = read(stats->common->socket, ackPacket, ackpacket_length);
-	    WARN_errno(rc < 0, "read");
-	    if (rc < 0)
+	    rc = read(stats->common->socket, ackPacket, readlen);
+	    WARN_errno(rc < 0, "ack await silence");
+	    if ((rc < 0) && FATALUDPREADERR(errno)) {
 		break;
-	    if (rc > 0) {
-#ifdef HAVE_THREAD_DEBUG
-		thread_debug("UDP server thinks server stats packet lost, will retransmit and try again", rc);
-#endif
 	    }
+#ifdef HAVE_THREAD_DEBUG
+	    if (rc > 0) {
+		thread_debug("UDP server thinks server stats packet maybe lost, will retransmit and try again", rc);
+	    }
+#endif
 	}
 	free(ackPacket);
     }
